@@ -8,7 +8,10 @@ from weather_in import __version__, api_key
 def main():
     city = sys.argv[1]
     state = sys.argv[2]
-    country = sys.argv[3]
+    if sysargv[3]:
+        country = sys.argv[3]
+    else:
+        country = "USA"#1
     url = "https://api.openweathermap.org/data/2.5/weather?q=%s,%s,%s&appid=%s&units=imperial" % (city, state, country, api_key)
     try:
         response = requests.get(url)
@@ -22,7 +25,7 @@ def main():
         print(str("high of: ")+str(high))
         print(str(deets))
     except KeyError:
-        print("The API expects City State passed as arguments.  Example: Pasadena California (note: CA will not work)")
+        print("The API expects City State Country passed as arguments.  Example: Pasadena California USA (note: CA will not work)")
     except:
         print("Whoops, I'm not sure what happened here.  Good luck!")
 if __name__ == '__main__':
